@@ -78,6 +78,17 @@ void	itemview_add_item(itemPtr item);
  */
 void	itemview_remove_item(itemPtr item);
 
+/**
+ * Notifies item view set currently an invalid (unwanted) selection
+ * is active which might need to be reset when selected the same
+ * item again.
+ *
+ * FIXME: This is a workaround for the problematic item selection solution.
+ *
+ * @param item		the incorrectly selected item
+ */
+void	itemview_set_invalid_selection (itemPtr item);
+
 /**
  * Selects a given item in the view. The item must be
  * added using itemview_add_item before selecting.
